Crate kcr_craftypath_github_io

Crate kcr_craftypath_github_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the craftypath.github.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

craftypath.github.io/v1alpha1

  • SopsSecret

Modules

v1alpha1